@@ -9,8 +9,8 @@
 #' in examples below.
 #'
 #' @details
-#' This parameter is used in [embed::step_umap()].
-#' 
+#' This parameter is used in `embed::step_umap()`.
+#'
 #' @examples
 #' values_initial_umap
 #' initial_umap()
@@ -26,5 +26,13 @@ initial_umap <- function(values = values_initial_umap) {
 
 #' @rdname initial_umap
 #' @export
-values_initial_umap <- c("spectral", "normlaplacian", "random", "lvrandom",
-                         "laplacian", "pca", "spca", "agspectral")
+values_initial_umap <- c(
+  "spectral",
+  "normlaplacian",
+  "random",
+  "lvrandom",
+  "laplacian",
+  "pca",
+  "spca",
+  "agspectral"
+)
